UI/UserInterface.py

changeset 4216
bca19a75be32
parent 4197
43199b5d5cfe
child 4392
7ce50a66cff0
--- a/UI/UserInterface.py	Sun Apr 12 16:59:06 2015 +0200
+++ b/UI/UserInterface.py	Sun Apr 12 18:00:45 2015 +0200
@@ -577,8 +577,10 @@
         SpellChecker.setDefaultLanguage(
             Preferences.getEditor("SpellCheckingDefaultLanguage"))
         
         # attribute for the last shown configuration page
         self.__lastConfigurationPageName = ""
+        self.__expandedConfigurationEntries = []
         
     def __createLayout(self, debugServer):
         """
@@ -5204,7 +5206,10 @@
         @param pageName name of the configuration page to show (string)
         """
         from Preferences.ConfigurationDialog import ConfigurationDialog
-        dlg = ConfigurationDialog(self, 'Configuration')
+        dlg = ConfigurationDialog(
+            self, 'Configuration',
+            expandedEntries=self.__expandedConfigurationEntries,
+        )
         dlg.preferencesChanged.connect(self.__preferencesChanged)
         dlg.masterPasswordChanged.connect(self.__masterPasswordChanged)
         dlg.show()
@@ -5221,6 +5226,7 @@
             Preferences.syncPreferences()
             self.__preferencesChanged()
         self.__lastConfigurationPageName = dlg.getConfigurationPageName()
+        self.__expandedConfigurationEntries = dlg.getExpandedEntries()
         
     def __exportPreferences(self):
         """
@@ -577,8 +577,10 @@
             Preferences.getEditor("SpellCheckingDefaultLanguage"))
         
-        # attribute for the last shown configuration page
+        # attributes for the last shown configuration page and the
+        # extended configuration entries
         self.__lastConfigurationPageName = ""

eric ide

mercurial